__version__ = "0.3.11"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.3.11)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '1ad4c860f72a3c7c53e5f09509596a1796ec6ff8'
__git_head_subject__ = 'Finished Release v0.3.11'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2016-12-18 14:13:05'
